@@ -7,8 +7,9 @@ class MySQLClient:
         '''
         初始化数据库连接
         :param dbdata host 主机地址,user 用户名,password 密码,database 数据库,port 端口，默认3306
-        return {bool} True/False
+        :return {bool} True/False
         '''
+        print('执行了一次')
         # 打开数据库连接
         self.db = pymysql.connect(
             host=dbdata['host'],
@@ -20,12 +21,16 @@ class MySQLClient:
         # 使用cursor()方法获取操作游标
         self.cursor = self.db.cursor()
 
-    def insert(self, table: str, data: dict):
+    def close(self):
+        self.db.close()
+
+    def insert(self, table: str, data: dict, close: bool = True):
         '''
         插入数据
         :param table 表名
         :param data 需要插入的数据
-        return {bool} True/False
+        :param close 是否自动关闭数据库连接，默认True
+        :return {bool} True/False
         '''
         result = False
         # 列
@@ -50,15 +55,17 @@ class MySQLClient:
             # 如果发生错误则回滚
             self.db.rollback()
             result = False
-        self.db.close()
+        if close:
+            self.close()
         return result
 
-    def fetch(self, fields: list, table: str, query: str):
+    def fetch(self, fields: list, table: str, query: str, close: bool = True):
         '''
         查询数据
         :param fields 要查询的字段名
         :param table 表名
         :param query 查询条件
+        :param close 是否自动关闭数据库连接，默认True
         :return {tuple}
         '''
         sql = 'SELECT %s FROM %s WHERE %s' % (
@@ -74,16 +81,18 @@ class MySQLClient:
         except:
             print("Error: unable to fetch data")
         # 关闭数据库连接
-        self.db.close()
+        if close:
+            self.close()
         return results
 
-    def update(self, table: str, set: str, query: str):
+    def update(self, table: str, set: str, query: str, close: bool = True):
         '''
         更新数据
         :param table 表名
         :param set 修改内容
         :param query 查询条件
-        return {bool} True/False
+        :param close 是否自动关闭数据库连接，默认True
+        :return {bool} True/False
         '''
         result = False
         sql = 'UPDATE %s SET %s WHERE %s' % (
@@ -102,15 +111,17 @@ class MySQLClient:
             self.db.rollback()
             result = False
         # 关闭数据库连接
-        self.db.close()
+        if close:
+            self.close()
         return result
 
-    def delete(self, table: str, query: str):
+    def delete(self, table: str, query: str, close: bool = True):
         '''
         删除数据
         :param table 表名
         :param query 查询条件
-        return {bool} True/False
+        :param close 是否自动关闭数据库连接，默认True
+        :return {bool} True/False
         '''
         result = False
         sql = 'DELETE FROM %s WHERE %s' % (
@@ -128,7 +139,8 @@ class MySQLClient:
             self.db.rollback()
             result = False
         # 关闭数据库连接
-        self.db.close()
+        if close:
+            self.close()
         return result
 
 
