@@ -3,7 +3,7 @@ import random
 import hashlib
 import binascii
 import os
-from unittest import result
+import json
 from pymoran.timetool import TimeClass
 
 
@@ -98,13 +98,64 @@ class StrClass:
         result = result.replace('/', '')
         return result
 
+    # def symbol_replace(self,val):
+    #     '''
+    #     替换文本中的特殊字符
+    #     :param val {str} 需要替换的字符串
+    #     :return {str} 替换后的字符串
+    #     '''
+    #     val=val.replace('\'','&#39;')
+    #     val=val.replace('´','&#180;')
+    #     val=val.replace('`','&#96;')
+    #     return val
+
+class JsonClass:
+    def __init__(self):
+        pass
+
+    def jsonToDumps(self, data:dict):
+        '''
+        将字典类型数据转换成str
+        :param data 字典类型数据
+        :return {str} 转换后的json格式字符串
+        '''
+        return json.dumps(data)
+
+    def jsonToLoads(self, jsonstr:str):
+        '''
+        将json字符串数据转换成字典类型
+        :param jsonstr json字符串
+        :return {dict} 转换后的dict数据
+        '''
+        if jsonstr == None:
+            return jsonstr
+        elif type(jsonstr) == bytes:
+            jsonstr = jsonstr.decode()
+        return json.loads(jsonstr)
+
+    # def jsonQuerySetToDumps(self, data):
+    #     '''
+    #     转换QuerySet类型数据并输出json格式字符串
+    #     :param data {QuerySet} QuerySet/list数据
+    #     :return {str} 转换后的json格式字符串
+    #     '''
+    #     if type(data) != list:
+    #         data = list(data)
+    #     result = json.dumps(data, ensure_ascii=False, cls=DjangoJSONEncoder)
+    #     return result
+
+    # def jsonQuerySetToLoads(self, data):
+    #     '''
+    #     转换QuerySet类型数据并输出dict
+
+    #     @param data {QuerySet} QuerySet/list数据
+
+    #     return {dict} 转换后的dict数据
+    #     '''
+    #     result = self.jsonQuerySetToDumps(data)
+    #     result = json.loads(result)
+    #     return result
+
 
 if __name__ == '__main__':
-    strclass = StrClass()
-    print(strclass.access_token('11'))
-
-    # def creat_ordernum():
-    #     ordernum = time.time()*1000000
-    #     ordernum = int(ordernum)
-    #     ranNum = random.randint(10, 99)
-    #     return str(ordernum)+str(ranNum)
+    pass
