@@ -1,3 +1,4 @@
+from sys import ps1
 import time
 
 
@@ -34,4 +35,4 @@ class TimeClass:
 
 
 if __name__=='__main__':
-    timeclass=TimeClass()
+    pass
